@@ -22,7 +22,7 @@ shed = Watershed(
        )
 
 shed.extract_data_pixels() 
-print "Displaying the original image:"
+print("Displaying the original image:")
 shed.display_data_image()
 shed.compute_LoG_image()
 
